@@ -10,7 +10,7 @@ my %DOM_SEL = (
   ':desc'      => ['meta[property="og:description"]', 'meta[name="twitter:description"]', 'meta[name="description"]'],
   ':image'     => ['meta[property="og:image"]',       'meta[property="og:image:url"]',    'meta[name="twitter:image"]'],
   ':site_name' => ['meta[property="og:site_name"]',   'meta[property="twitter:site"]'],
-  ':title' => ['meta[property="og:title"]', 'meta[name="twitter:title"]', 'title'],
+  ':title'     => ['meta[property="og:title"]',       'meta[name="twitter:title"]', 'title'],
 );
 
 my @JSON_ATTRS = (
@@ -79,7 +79,7 @@ sub _el {
   @sel = @{$DOM_SEL{$sel[0]}} if $DOM_SEL{$sel[0]};
 
   for my $sel (@sel) {
-    my $e = $dom->at($sel) or next;
+    my $e     = $dom->at($sel) or next;
     my ($val) = grep {$_} map { trim($_ // '') } $e->{content}, $e->{value}, $e->{href}, $e->text, $e->all_text;
     return $val if defined $val;
   }
@@ -360,12 +360,12 @@ __DATA__
 @@ rich.html.ep
 % if ($l->title) {
   % if (my $thumbnail_url = $l->thumbnail_url || $l->placeholder_url) {
-<div class="le-card le-image-card le-<%= $l->type %> le-provider-<%= lc $l->provider_name %>">
+<div class="le-<%= $l->type %> le-card le-image-card le-provider-<%= lc $l->provider_name %>">
     <a href="<%= $l->url %>" class="le-thumbnail<%= $l->thumbnail_url ? '' : '-placeholder' %>">
       <img src="<%= $thumbnail_url %>" alt="<%= $l->author_name || 'Placeholder' %>">
     </a>
   % } else {
-<div class="le-card le-<%= $l->type %> le-provider-<%= lc $l->provider_name %>">
+<div class="le-<%= $l->type %> le-card le-provider-<%= lc $l->provider_name %>">
   % }
   <h3><%= $l->title %></h3>
     % if ($l->description) {
